@@ -1,7 +1,6 @@
 import logging
 from ..basic.core import SitesCore
 import os
-import shutil
 import traceback
 
 
@@ -18,12 +17,12 @@ class QuickbooksCore(SitesCore):
         return ''
 
     def login_to_site(self) -> bool:
+        self.is_site_available = False
         self.browser.close_browser()
 
         if self.temp_folder:
-            if os.path.exists(self.temp_folder):
-                shutil.rmtree(self.temp_folder)
-            os.mkdir(self.temp_folder)
+            if not os.path.exists(self.temp_folder):
+                os.mkdir(self.temp_folder)
             self.browser.set_download_directory(self.temp_folder, True)
 
         for i in range(1, 4):
@@ -43,6 +42,7 @@ class QuickbooksCore(SitesCore):
                     self.browser.click_element_when_visible('//button[@id="ius-sign-in-submit-btn"]')
                 else:
                     self.browser.click_element_when_visible('//button[@id="ius-sign-in-submit-btn"]')
+                    self.wait_element('//input[@id="ius-sign-in-mfa-password-collection-current-password"]')
                     self.browser.input_text('//input[@id="ius-sign-in-mfa-password-collection-current-password"]', self.password)
                     self.browser.click_element_when_visible('//input[@id="ius-sign-in-mfa-password-collection-continue-btn"]')
 
@@ -51,6 +51,7 @@ class QuickbooksCore(SitesCore):
                     self.browser.click_element_when_visible('//span[@id="ius-sublabel-mfa-email-otp"]')
                     self.browser.click_element_when_visible('//input[@id="ius-mfa-options-submit-btn"]')
 
+                    self.wait_element('//input[@id="ius-mfa-confirm-code"]')
                     self.browser.input_text(
                         '//input[@id="ius-mfa-confirm-code"]',
                         self.get_otp_code()
@@ -59,6 +60,7 @@ class QuickbooksCore(SitesCore):
                 self.wait_element('//div[@data-automation-id="cm_client_hub_business_name"]')
                 if self.does_element_displayed('//div[@data-automation-id="cm_client_hub_business_name"]'):
                     self.base_url = self.get_base_url(self.browser.get_location())
+                    self.is_site_available = True
                     return True
             except Exception as ex:
                 logging.error(f'Login failed. Attempt {i}', 'ERROR')
@@ -77,9 +79,10 @@ class QuickbooksCore(SitesCore):
         :param client_name: Client name
         :return: None
         """
-        self.browser.click_element_when_visible('//span[text()="GO TO QUICKBOOKS"]')
-        self.wait_element(f'//span[text()="{client_name}"]')
-        self.browser.click_element_when_visible(f'//span[text()="{client_name}"]')
+        self.click_bunch_of_elements([
+            '//span[text()="GO TO QUICKBOOKS"]',
+            f'//span[text()="{client_name}"]'
+        ])
         self.wait_element(f'//div[contains(@class, "companyName") and text()="{client_name}"]')
 
     def open_add_invoice_page(self) -> None:
@@ -88,9 +91,10 @@ class QuickbooksCore(SitesCore):
         """
         self.browser.go_to(f'{self.base_url}/app/homepage')
 
-        self.browser.click_element_when_visible('//button[@data-id="global_create_button"]')
-        self.wait_element('//a[@data-id="invoice"]')
-        self.browser.click_element_when_visible('//a[@data-id="invoice"]')
+        self.click_bunch_of_elements([
+            '//button[@data-id="global_create_button"]',
+            '//a[@data-id="invoice"]'
+        ])
 
     def open_invoices_page(self) -> None:
         """
